import { type ObjectEmitsOptions, type PropType, type Ref } from 'vue-demi';
interface Emits extends ObjectEmitsOptions {
    /** After rendering */
    (event: 'render', value: string | Uint8Array): void;
}
/** Vue Markdown Component */
declare const _default: import("vue-demi").DefineComponent<{
    /** Model value */
    modelValue: {
        type: PropType<string | ArrayLike<number>>;
        default: string;
    };
    /**
     * Using tag
     */
    tag: {
        type: StringConstructor;
        default: string;
    };
    /** Customize parsing */
    parseFlags: {
        type: PropType<ParseFlags>;
        default: any;
    };
    /** Select output format. */
    format: {
        type: PropType<"html" | "xhtml">;
        default: string;
    };
    /**
     * bytes=true causes parse() to return the result as a Uint8Array instead of a string.
     *
     * The returned Uint8Array is only valid until the next call to parse().
     * If you need to keep the returned data around, call Uint8Array.slice() to make a copy,
     * as each call to parse() uses the same underlying memory.
     *
     * This only provides a performance benefit when you never need to convert the output
     * to a string. In most cases you're better off leaving this unset or false.
     */
    bytes: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** Allow "javascript:" in links */
    allowJsUri: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Optional callback which if provided is called for each code block.
     * langname holds the "language tag", if any, of the block.
     *
     * The returned value is inserted into the resulting HTML verbatim, without HTML escaping.
     * Thus, you should take care of properly escaping any special HTML characters.
     *
     * If the function returns null or undefined, or an exception occurs, the body will be
     * included as-is after going through HTML escaping.
     *
     * Note that use of this callback has an adverse impact on performance as it casues
     * calls and data to be bridged between WASM and JS on every invocation.
     */
    onCodeBlock: {
        type: PropType<(langname: string, body: UTF8Bytes) => Uint8Array | string | null | undefined>;
        default: () => undefined;
    };
}, {
    placeholder: Ref<HTMLElement | undefined>;
    html: Ref<string | Uint8Array>;
    render: (markdown?: string | ArrayLike<number>, config?: ParseOptions) => Promise<string | Uint8Array>;
}, unknown, {}, {}, import("vue-demi").ComponentOptionsMixin, import("vue-demi").ComponentOptionsMixin, Emits, "render", import("vue-demi").VNodeProps & import("vue-demi").AllowedComponentProps & import("vue-demi").ComponentCustomProps, Readonly<import("vue-demi").ExtractPropTypes<{
    /** Model value */
    modelValue: {
        type: PropType<string | ArrayLike<number>>;
        default: string;
    };
    /**
     * Using tag
     */
    tag: {
        type: StringConstructor;
        default: string;
    };
    /** Customize parsing */
    parseFlags: {
        type: PropType<ParseFlags>;
        default: any;
    };
    /** Select output format. */
    format: {
        type: PropType<"html" | "xhtml">;
        default: string;
    };
    /**
     * bytes=true causes parse() to return the result as a Uint8Array instead of a string.
     *
     * The returned Uint8Array is only valid until the next call to parse().
     * If you need to keep the returned data around, call Uint8Array.slice() to make a copy,
     * as each call to parse() uses the same underlying memory.
     *
     * This only provides a performance benefit when you never need to convert the output
     * to a string. In most cases you're better off leaving this unset or false.
     */
    bytes: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** Allow "javascript:" in links */
    allowJsUri: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Optional callback which if provided is called for each code block.
     * langname holds the "language tag", if any, of the block.
     *
     * The returned value is inserted into the resulting HTML verbatim, without HTML escaping.
     * Thus, you should take care of properly escaping any special HTML characters.
     *
     * If the function returns null or undefined, or an exception occurs, the body will be
     * included as-is after going through HTML escaping.
     *
     * Note that use of this callback has an adverse impact on performance as it casues
     * calls and data to be bridged between WASM and JS on every invocation.
     */
    onCodeBlock: {
        type: PropType<(langname: string, body: UTF8Bytes) => Uint8Array | string | null | undefined>;
        default: () => undefined;
    };
}>> & {
    [x: `on${Capitalize<string>}`]: ((...args: never) => any) | undefined;
}, {
    modelValue: string | ArrayLike<number>;
    tag: string;
    parseFlags: ParseFlags;
    format: "html" | "xhtml";
    bytes: boolean;
    allowJsUri: boolean;
    onCodeBlock: (langname: string, body: UTF8Bytes) => Uint8Array | string | null | undefined;
}>;
export default _default;
//# sourceMappingURL=VueMarkdown.d.ts.map