/**
 * h-demi - h function for Vue 2 and 3
 *
 * @see {@link https://github.com/vueuse/vue-demi/issues/65}
 */
import { h as hDemi, isVue2, Vue2 } from 'vue-demi';
const adaptOnsV3 = (ons) => {
    if (!ons)
        return {};
    return Object.entries(ons).reduce((ret, [key, handler]) => {
        key = key.charAt(0).toUpperCase() + key.slice(1);
        key = `on${key}`;
        return { ...ret, [key]: handler };
    }, {});
};
const h = (type, options = {}, chidren) => {
    if (isVue2 && parseInt(Vue2.version) < 2.7) {
        // Makeshift support :(
        // Since Vue2.7 includes the Composition API, the functions in vue-demi are not used.
        return hDemi(type, options, chidren);
    }
    const { props, domProps, on, ...extraOptions } = options;
    const ons = on ? adaptOnsV3(on) : {};
    return hDemi(type, { ...extraOptions, ...props, ...domProps, ...ons }, chidren);
};
const slot = (defaultSlots) => typeof defaultSlots == 'function' ? defaultSlots() : defaultSlots;
export { slot, h as default };
